package com.ruoyi.service.impl;

import java.util.List;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.SecurityUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.mapper.AutomobileEnterpriseMapper;
import com.ruoyi.domain.AutomobileEnterprise;
import com.ruoyi.service.IAutomobileEnterpriseService;

/**
 * 车企信息Service业务层处理
 *
 * @author gxk
 * @date 2024-01-05
 */
@Service
public class AutomobileEnterpriseServiceImpl implements IAutomobileEnterpriseService
{
    @Autowired
    private AutomobileEnterpriseMapper automobileEnterpriseMapper;

    /**
     * 查询车企信息
     *
     * @param id 车企信息主键
     * @return 车企信息
     */
    @Override
    public AutomobileEnterprise selectAutomobileEnterpriseById(Long id)
    {
        return automobileEnterpriseMapper.selectAutomobileEnterpriseById(id);
    }

    /**
     * 查询车企信息列表
     *
     * @param automobileEnterprise 车企信息
     * @return 车企信息
     */
    @Override
    public List<AutomobileEnterprise> selectAutomobileEnterpriseList(AutomobileEnterprise automobileEnterprise)
    {
        return automobileEnterpriseMapper.selectAutomobileEnterpriseList(automobileEnterprise);
    }

    /**
     * 新增车企信息
     *
     * @param automobileEnterprise 车企信息
     * @return 结果
     */
    @Override
    public int insertAutomobileEnterprise(AutomobileEnterprise automobileEnterprise)
    {
        automobileEnterprise.setCreateTime(DateUtils.getNowDate());
        automobileEnterprise.setCreateBy(String.valueOf(SecurityUtils.getUserId()));
        return automobileEnterpriseMapper.insertAutomobileEnterprise(automobileEnterprise);
    }

    /**
     * 修改车企信息
     *
     * @param automobileEnterprise 车企信息
     * @return 结果
     */
    @Override
    public int updateAutomobileEnterprise(AutomobileEnterprise automobileEnterprise)
    {
        automobileEnterprise.setUpdateTime(DateUtils.getNowDate());
        automobileEnterprise.setUpdateBy(String.valueOf(SecurityUtils.getUserId()));
        return automobileEnterpriseMapper.updateAutomobileEnterprise(automobileEnterprise);
    }

    /**
     * 批量删除车企信息
     *
     * @param ids 需要删除的车企信息主键
     * @return 结果
     */
    @Override
    public int deleteAutomobileEnterpriseByIds(Long[] ids)
    {
        return automobileEnterpriseMapper.deleteAutomobileEnterpriseByIds(ids);
    }

    /**
     * 删除车企信息信息
     *
     * @param id 车企信息主键
     * @return 结果
     */
    @Override
    public int deleteAutomobileEnterpriseById(Long id)
    {
        return automobileEnterpriseMapper.deleteAutomobileEnterpriseById(id);
    }
}
