package com.ruoyi.web;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.ruoyi.common.annotation.Anonymous;
import com.ruoyi.common.core.domain.R;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.domain.AutomobileEnterprise;
import com.ruoyi.service.IAutomobileEnterpriseService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 车企信息Controller
 *
 * @author gxk
 * @date 2024-01-05
 */
@Api(tags = {"车企信息"})
@RestController
@RequestMapping("/system/enterprise")
public class AutomobileEnterpriseController extends BaseController
{
    @Autowired
    private IAutomobileEnterpriseService automobileEnterpriseService;

    /**
     * 查询车企信息列表
     */
    @ApiOperation("分页查询车企信息列表")
    @GetMapping("/list")
    public TableDataInfo list(AutomobileEnterprise automobileEnterprise)
    {
        startPage();
        List<AutomobileEnterprise> list = automobileEnterpriseService.selectAutomobileEnterpriseList(automobileEnterprise);
        return getDataTable(list);
    }

    /**
     * 导出车企信息列表
     */
    @Log(title = "车企信息", businessType = BusinessType.EXPORT)
    @ApiOperation("导出车企信息列表")
    @PostMapping("/export")
    public void export(HttpServletResponse response, AutomobileEnterprise automobileEnterprise)
    {
        List<AutomobileEnterprise> list = automobileEnterpriseService.selectAutomobileEnterpriseList(automobileEnterprise);
        ExcelUtil<AutomobileEnterprise> util = new ExcelUtil<AutomobileEnterprise>(AutomobileEnterprise.class);
        util.exportExcel(response, list, "车企信息数据");
    }

    /**
     * 获取车企信息详细信息
     */
    @ApiOperation("获取车企信息详细信息")
    @GetMapping(value = "/{id}")
    public R getInfo(@PathVariable("id") Long id)
    {
        return R.ok(automobileEnterpriseService.selectAutomobileEnterpriseById(id));
    }

    /**
     * 新增车企信息
     */
    @ApiOperation("新增车企信息")
    @Log(title = "车企信息", businessType = BusinessType.INSERT)
    @PostMapping
    public R add(@RequestBody AutomobileEnterprise automobileEnterprise)
    {
        return R.ok(automobileEnterpriseService.insertAutomobileEnterprise(automobileEnterprise));
    }

    /**
     * 修改车企信息
     */
    @ApiOperation("修改车企信息")
    @Log(title = "车企信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public R edit(@RequestBody AutomobileEnterprise automobileEnterprise)
    {
        return R.ok(automobileEnterpriseService.updateAutomobileEnterprise(automobileEnterprise));
    }

    /**
     * 删除车企信息
     */
    @ApiOperation("删除车企信息")
    @Log(title = "车企信息", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public R remove(@PathVariable Long[] ids)
    {
        return R.ok(automobileEnterpriseService.deleteAutomobileEnterpriseByIds(ids));
    }
}
